@@ -8,7 +8,8 @@ use Scalar::Util;
 
 use Carp;
 
-use parent qw{Elive::Connection};
+use Elive::Connection;
+use base qw{Elive::Connection};
 
 use Elive;
 use Elive::Util;
@@ -16,31 +17,6 @@ use Elive::Entity;
 use Elive::Entity::User;
 use Elive::Entity::ServerDetails;
 
-=head1 NAME
-
-Elive::Connection::SDK - Manage Elluminate Live SDK SOAP connections.
-
-=head1 DESCRIPTION
-
-This module handles logical connections to Elluminate I<Live!> sites.
-
-Most of the time, you won't need to use this module directly, rather
-you'll create a default connection via L<Elive>:
-
-    Elive->connect('http://someserver.com', 'someuser', 'somepass');
-
-However, if you need to manage multiple sites and/or servers. You can
-have multiple connections:
-
-    my $connection1
-            = Elive::Connection->connect('http://someserver.com/site1',
-                                        'user1' => 'pass1');
-
-    my $connection2
-            = Elive::Connection->connect('http://user2:pass2@someserver.com/site2');
-
-=cut
-
 __PACKAGE__->mk_accessors( qw{_login _server_details} );
 
 our %KnownCommands = (
@@ -111,7 +87,6 @@ our %KnownCommands = (
 	streamPreload => 'u',
 	streamRecording => 'u',
 
-	updateGroup => 'u',
 	updateMeeting => 'u',
 	updateMeetingParameters => 'u',
 	updateRecording => 'u',
@@ -304,14 +279,4 @@ sub server_details {
     return $server_details;
 }
 
-=head2 version
-
-Return the Elluminate I<Live!> Manager version
-
-=cut
-
-sub version {
-    return (my $self = shift)->server_details->version;
-}
-
 1;
