@@ -8,6 +8,7 @@ use Elive::Util;
 
 __PACKAGE__->entity_name('Recording');
 __PACKAGE__->collection_name('Recordings');
+__PACKAGE__->derivable(url => 'web_url');
 
 has 'recordingId' => (is => 'rw', isa => 'Str', required => 1);
 __PACKAGE__->primary_key('recordingId');
@@ -75,18 +76,14 @@ sub download {
     die "unable to get a recording_id"
 	unless $recording_id;
 
-    my $adapter = $self->check_adapter('getRecordingStream');
-
     my $connection = $self->connection
 	or die "not connected";
 
-    my $som = $connection->call($adapter,
+    my $som = $connection->call('getRecordingStream',
 				recordingId => $recording_id,
 	);
 
-    $self->_check_for_errors($som);
-
-    my $results = $self->_get_results($som);
+    my $results = $self->_get_results($som, $connection);
 
     return  Elive::Util::_hex_decode($results->[0])
 	if $results->[0];
@@ -142,12 +139,10 @@ sub upload {
 
     if ($size && $binary_data) {
 
-	my $adapter = $class->check_adapter('streamRecording');
-
 	my $connection = $self->connection
 	    or die "not connected";
 
-	my $som = $connection->call($adapter,
+	my $som = $connection->call('streamRecording',
 				    recordingId => $self->recordingId,
 				    length => $size,
 				    stream => (SOAP::Data
@@ -155,7 +150,7 @@ sub upload {
 					       ->value($binary_data)),
 	    );
 
-	$self->_check_for_errors($som);
+	$connection->_check_for_errors($som);
     }
 
     return $self;
@@ -264,7 +259,7 @@ Preferences E<gt>E<gt> Session Access E<gt>E<gt> Lock Recording Playback to Clie
 
 It represents a fixed client IP address for launching the recording playback.
 
-See also L<http://en.wikipedia.org/wiki/JNLP>.
+See also L<http://wikipedia.org/wiki/JNLP>.
 
 =cut
 
@@ -292,17 +287,11 @@ sub buildJNLP {
 	$soap_params{'userId'} = Elive::Util::_freeze($_, 'Str');
     }
 
-    my $adapter = $self->check_adapter('buildRecordingJNLP');
+    my $som = $connection->call('buildRecordingJNLP', %soap_params);
 
-    my $som = $connection->call($adapter,
-				%soap_params,
-				);
+    my $results = $self->_get_results($som, $connection);
 
-    $self->_check_for_errors($som);
-
-    my $results = $self->_unpack_as_list($som->result);
-
-    return @$results && Elive::Util::_thaw($results->[0], 'Str');
+    return @$results && $results->[0];
 }
 
 1;
