@@ -56,10 +56,12 @@ In particular meeting participants stringify to userId=role, eg
 BEGIN {
     __PACKAGE__->mk_classdata('_entities' => {});
     __PACKAGE__->mk_classdata('_aliases');
+    __PACKAGE__->mk_classdata('_derivable' => {});
     __PACKAGE__->mk_classdata('_entity_name');
-    __PACKAGE__->mk_classdata('_primary_key', []);
+    __PACKAGE__->mk_classdata('_primary_key' => []);
+    __PACKAGE__->mk_classdata('_params' => {});
     __PACKAGE__->mk_classdata('collection_name');
-    __PACKAGE__->mk_classdata('isa');
+    __PACKAGE__->mk_classdata('_isa');
 };
 
 use Scalar::Util;
@@ -260,15 +262,45 @@ sub id {
 sub primary_key {
     my ($entity_class, @pkey) = @_;
 
-    if (@pkey) {
-
-	$entity_class->_primary_key(\@pkey);
-
-    }
+    $entity_class->_primary_key(\@pkey)
+	if (@pkey);
 
     return @{$entity_class->_primary_key};
 }
 
+=head2 params
+
+    Setter/getter for parameter field(s) for this entity class
+
+    Elive::Entity::User->params(loginName => 'Str');
+    my %params = MyApp::Entity::User->params;
+
+=cut
+
+sub params {
+    my ($entity_class, %params) = @_;
+
+    $entity_class->_params(\%params)
+	if (keys %params);
+
+    return %{$entity_class->_params};
+}
+
+=head2 derivable
+
+    Setter/getter for derivable field(s) for this entity class
+
+=cut
+
+sub derivable {
+    my ($entity_class, %derivable) = @_;
+
+    $entity_class->_derivable(\%derivable)
+	if (keys %derivable);
+
+    return %{$entity_class->_derivable};
+}
+
 =head2 entities
 
     my $entities = Entity::Entity->entities
@@ -568,7 +600,7 @@ sub AUTOLOAD {
 	goto $subref;
     }
     else {
-	die $class.": unknown method $method";
+	Carp::croak $class.": unknown method $method";
     }
 }
 
